@@ -2,7 +2,7 @@ package WWW::Shorten::0rz;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 use base qw( WWW::Shorten::generic Exporter );
 our @EXPORT = qw( makeashorterlink makealongerlink );
 
@@ -42,9 +42,24 @@ WWW::Shorten::0rz - Shorten URL using 0rz.tw
   use WWW::Shorten '0rz';
   my $short_url = makeashorterlink($longurl);
 
+=head1 METHODS
+
+=over
+
+=item makeashorterlink( $url )
+
+Given a very long $url, make it shorter using 0rz.tw url shorten
+service.
+
+=item makealongerlink( $url )
+
+Given a shorted $url, turn it to back to its longer version.
+
+=back
+
 =head1 COPYRIGHT
 
-Copyright 2004 by Kang-min Liu <gugod@gugod.org>.
+Copyright 2004-2007 by Kang-min Liu <gugod@gugod.org>.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
